@@ -89,7 +89,7 @@ class CryptoInterface(rpc.Controller):
         except:
             request.app.log.error(
                 'Invalid request', 'RPC', logging.WARNING, True)
-            raise errors.RequestError('Invalid request', -32700)
+            raise errors.RequestError('Invalid request')
 
         request.app.log.error('Call {} {}'.format(
             rpc_method, rpc_params), 'RPC', logging.INFO, True)
